@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_iam._jsii
@@ -17,7 +17,7 @@ import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-gitlab-runner", "1.61.1", __name__[0:-6], "cdk-gitlab-runner@1.61.1.jsii.tgz"
+    "cdk-gitlab-runner", "1.61.5", __name__[0:-6], "cdk-gitlab-runner@1.61.5.jsii.tgz"
 )
 
 __all__ = [
